documentationtools.ClassCrawler
===============================

.. abjad-lineage:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler

.. autoclass:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.code_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.include_private_objects
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.module_crawler
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.root_package_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__repr__
   :noindex:
